/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.geronimo.samples.order;

import java.io.IOException;

import javax.annotation.Resource;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.Queue;
import javax.jms.Connection;
import javax.jms.Session;
import javax.jms.MessageProducer;
import javax.jms.TextMessage;
import javax.jms.JMSException;
import javax.jms.TextMessage;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class OrderSenderServlet extends HttpServlet {

	@Resource(name="CommonConnectionFactory")
	private ConnectionFactory factory;

	@Resource(name="OrderQueue")
	private Queue receivingQueue;

	public void init() throws ServletException {
		super.init();		
	}

	protected void doGet(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
		manageOrders(req,res);
	}

	protected void doPost(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
		doGet(req,res);
	}
	
	private void manageOrders(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException{
	    String path = "/jsp/error.jsp";
	    Connection connection = null;
		MessageProducer messageProducer = null;
		Session sess = null;
		try
	    {
			String customerId = req.getParameter("customerId");
		    String orderId = req.getParameter("orderId");
		    String qty = req.getParameter("quantity");
		    String model = req.getParameter("model");
		    
		    if(!customerId.equals("") && !orderId.equals("") && !qty.equals("")){
		    	System.out.println("Start Sending Order Request");
		    	// creating online order request
		    	String orderRequest = "<Order orderId=\""+orderId+"\" custId=\""+customerId+"\" qty=\""+qty+"\" model=\""+model+"\"/>" ;
				connection = factory.createConnection();
				sess = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);	
				path = "/jsp/index.jsp";
				TextMessage msg = sess.createTextMessage("<OrderId=" + orderId + " CustomerId=" + customerId
													+ " Quantity=" + qty + " Model=" + model + ">" );
				messageProducer = sess.createProducer(receivingQueue);
				messageProducer.send(msg);
				System.out.println("Order Request Send");
		    } else{
		    	String error = "";
		    	
		    	if(customerId.equals("")){
		    		error = "Customer Id Cannot be Empty";
		    	}else if(orderId.equals("")){
		    		error = "Order Id Cannot be Empty";
		    	}else if(qty.equals("")){
		    		error = "Quantity Cannot be Empty";
		    	}
		    	req.setAttribute("error",error);
		    }
	      } catch (Exception e)
	      {
	    	  System.out.println("Error "+e);
	    	  e.printStackTrace();
	      }finally{
	    	  try {
	    		  if(messageProducer != null) messageProducer.close();
				  if(sess != null)sess.close();
				  if(connection!= null)connection.close();
			} catch (JMSException e) {
				e.printStackTrace();
			}
	   	  }
	      getServletContext().getRequestDispatcher(path).forward(req,res);
	}
}
